// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
const vscode = require('vscode');

// this method is called when your extension is activated
// your extension is activated the very first time the command is executed

/**
 * @param {vscode.ExtensionContext} context
 */
function activate(context) {

	console.log('CodaKid Forge extension loaded successfully');

	let runClient = vscode.commands.registerCommand('codakidforge.runClient', function () {
		
		vscode.window.showInformationMessage('Starting Minecraft client!')
		// Save all files
		vscode.commands.executeCommand('saveAll')
		// Clear old terminals
		clearTerminalsWithName('minecraft_client')
		// Create new terminal
		let terminal = vscode.window.createTerminal('minecraft_client')
		terminal.show()
		terminal.sendText('./gradlew runClient')

	});

	let runServer = vscode.commands.registerCommand('codakidforge.runServer', function () {

		vscode.window.showInformationMessage('Starting Minecraft server!')
		// Save all files
		vscode.commands.executeCommand('saveAll')
		// Clear old terminals
		clearTerminalsWithName('minecraft_server')
		// Create new terminal
		let terminal = vscode.window.createTerminal('minecraft_server')
		terminal.show()
		terminal.sendText('./gradlew runServer')

	});

	let buildMod = vscode.commands.registerCommand('codakidforge.buildMod', function () {

		vscode.window.showInformationMessage('Building your mod!')
		// Save all files
		vscode.commands.executeCommand('saveAll')
		// Build mod
		let terminal = vscode.window.createTerminal('minecraft_server')
		terminal.show()
		terminal.sendText('./gradlew build')

	})

	context.subscriptions.push(runClient);
	context.subscriptions.push(runServer);
	context.subscriptions.push(buildMod);
}

// this method is called when your extension is deactivated
function deactivate() {
	// Clear any terminals that might be running
	clearTerminalsWithName('minecraft_client')
	clearTerminalsWithName('minecraft_server')
}

// Disposes all terminals with the given name
function clearTerminalsWithName(terminalName) {
	let terminals = vscode.window.terminals.filter(element => element.name === terminalName)
	for (let i = terminals.length - 1; i >= 0; i--) {
		terminals[i].dispose()
	}
}

module.exports = {
	activate,
	deactivate
}
